# Release Notes

## 0.4.1 (2024-06-27)

- Fix CI issues.

## 0.4.0 (2024-06-27)

- Add sequence features.

## 0.3.0

- Add util module.

## 0.2.1

- Fix concat files does not have extension.

## 0.2.0

- Add all alignment features.
- Add genomic features.

## 0.1.0

- Initial release.
- Add alignment concatenation feature.
